# sp_mysql
This includes module for working with mysql database.
# Usage
This modlue will take some parameters from user so that you can minimize some lines of code and also you need not to remember all the queries all time it as simple that even you don't know the original syntax you can work with some of the queries of mysql.